Documentation
¶
Overview ¶
Package ipconv is a library providing utility functions to convert ip.
Index ¶
Constants ¶
const Version = "0.1.1"
Version of current package
Variables ¶
This section is empty.
Functions ¶
func SafeV42Long ¶
SafeV42Long converts an ipv4 string to an uint32 integer. An error returns if format of ip is not ipv4
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.